import{g as t}from"./index-B1MHyEgd.js";function e(t,e){return e.forEach(function(e){e&&"string"!=typeof e&&!Array.isArray(e)&&Object.keys(e).forEach(function(o){if("default"!==o&&!(o in t)){var r=Object.getOwnPropertyDescriptor(e,o);Object.defineProperty(t,o,r.get?r:{enumerable:!0,get:function(){return e[o]}})}})}),Object.freeze(t)}var o,r={exports:{}};var s,a=o?r.exports:(o=1,s="undefined"==typeof window?r.exports:window,r.exports=((t,e,o)=>(()=>{var r,s={512:t=>{t.exports=e},620:t=>{t.exports=o},944:e=>{e.exports=t}},a={};function i(t){var e=a[t];if(void 0!==e)return e.exports;var o=a[t]={exports:{}};return s[t](o,o.exports,i),o.exports}i.n=t=>{var e=t&&t.__esModule?()=>t.default:()=>t;return i.d(e,{a:e}),e},i.d=(t,e)=>{for(var o in e)i.o(e,o)&&!i.o(t,o)&&Object.defineProperty(t,o,{enumerable:!0,get:e[o]})},i.o=(t,e)=>Object.prototype.hasOwnProperty.call(t,e);var n={};i.d(n,{default:()=>E});var l=i(944),d=i.n(l);let{defaultOptions:h}=d(),{noop:c}=d(),{addEvent:p,extend:u,isObject:g,merge:f,relativeLength:m}=d(),x={radius:0,scope:"stack",where:void 0},y={optionsToObject:function(t,e){return g(t)||(t={radius:t||0}),f(x,e,t)}};var v=i(512),b=i.n(v),C=i(620);let{parse:R}=i.n(C)(),{merge:A}=d();!function(t){t.initDataClasses=function(t){let e,o,r,s=this.chart,a=this.legendItem=this.legendItem||{},i=this.options,n=t.dataClasses||[],l=s.options.chart.colorCount,d=0;this.dataClasses=o=[],a.labels=[];for(let t=0,a=n.length;t<a;++t)e=A(e=n[t]),o.push(e),(s.styledMode||!e.color)&&("category"===i.dataClassColor?(s.styledMode||(l=(r=s.options.colors||[]).length,e.color=r[d]),e.colorIndex=d,++d===l&&(d=0)):e.color=R(i.minColor).tweenTo(R(i.maxColor),a<2?.5:t/(a-1)))},t.initStops=function(){let t=this.options,e=this.stops=t.stops||[[0,t.minColor||""],[1,t.maxColor||""]];for(let t=0,o=e.length;t<o;++t)e[t].color=R(e[t][1])},t.normalizedValue=function(t){let e=this.max||0,o=this.min||0;return this.logarithmic&&(t=this.logarithmic.log2lin(t)),1-(e-t)/(e-o||1)},t.toColor=function(t,e){let o,r,s,a,i,n,l=this.dataClasses,d=this.stops;if(l){for(n=l.length;n--;)if(r=(i=l[n]).from,s=i.to,(void 0===r||t>=r)&&(void 0===s||t<=s)){a=i.color,e&&(e.dataClass=n,e.colorIndex=i.colorIndex);break}}else{for(o=this.normalizedValue(t),n=d.length;n--&&!(o>d[n][0]););r=d[n]||d[n+1],o=1-((s=d[n+1]||r)[0]-o)/(s[0]-r[0]||1),a=r.color.tweenTo(s.color,o)}return a}}(r||(r={}));let O=r,{extend:w}=d(),j=function(t){w(t,O)},{gauge:M,pie:I}=b().seriesTypes,{clamp:P,extend:_,isNumber:k,merge:T,pick:S,pInt:z}=d();class D extends M{translate(){let t=this.yAxis;j(t),!t.dataClasses&&t.options.dataClasses&&t.initDataClasses(t.options),t.initStops(),M.prototype.translate.call(this)}drawPoints(){let t,e=this.yAxis,o=e.center,r=this.options,s=this.chart.renderer,a=r.overshoot,i=r.rounded&&void 0===r.borderRadius,n=k(a)?a/180*Math.PI:0;for(let a of(k(r.threshold)&&(t=e.startAngleRad+e.translate(r.threshold,void 0,void 0,void 0,!0)),this.thresholdAngleRad=S(t,e.startAngleRad),this.points))if(!a.isNull){let t,l,d=z(S(a.options.radius,r.radius,100))*o[2]/200,h=z(S(a.options.innerRadius,r.innerRadius,60))*o[2]/200,c=Math.min(e.startAngleRad,e.endAngleRad),p=Math.max(e.startAngleRad,e.endAngleRad),u=a.graphic,g=e.startAngleRad+e.translate(a.y,void 0,void 0,void 0,!0),f=e.toColor(a.y,a),m=a.getClassName();"none"===f&&(f=a.color||this.color||"none"),"none"!==f&&(a.color=f),g=P(g,c-n,p+n),!1===r.wrap&&(g=P(g,c,p));let x=i?(d-h)/2/d:0,v=Math.min(g,this.thresholdAngleRad)-x,b=Math.max(g,this.thresholdAngleRad)+x;b-v>2*Math.PI&&(b=v+2*Math.PI);let C=i?"50%":0;r.borderRadius&&(C=y.optionsToObject(r.borderRadius).radius),a.shapeArgs=t={x:o[0],y:o[1],r:d,innerR:h,start:v,end:b,borderRadius:C},a.startR=d,u?(l=t.d,u.animate(_({fill:f},t)),l&&(t.d=l)):a.graphic=u=s.arc(t).attr({fill:f,"sweep-flag":0}).add(this.group),this.chart.styledMode?this.yAxis?.stops&&(m=m.replace(/highcharts-color-\d/gm,"").trim()):("square"!==r.linecap&&u.attr({"stroke-linecap":"round","stroke-linejoin":"round"}),u.attr({stroke:r.borderColor||"none","stroke-width":r.borderWidth||0})),u&&u.addClass(m)}}animate(t){t||(this.startAngleRad=this.thresholdAngleRad,I.prototype.animate.call(this,t))}}D.defaultOptions=T(M.defaultOptions,{colorByPoint:!0,dataLabels:{y:0}}),b().registerSeriesType("solidgauge",D);let E=d();return n.default})())(s._Highcharts,s._Highcharts.SeriesRegistry,s._Highcharts.Color)),i=e({__proto__:null,default:t(a)},[a]);export{i as s};
//# sourceMappingURL=solid-gauge-C-mGiAKW.js.map
