import{g as s}from"./index-B1MHyEgd.js";function e(s,e){return e.forEach(function(e){e&&"string"!=typeof e&&!Array.isArray(e)&&Object.keys(e).forEach(function(r){if("default"!==r&&!(r in s)){var t=Object.getOwnPropertyDescriptor(e,r);Object.defineProperty(s,r,t.get?t:{enumerable:!0,get:function(){return e[r]}})}})}),Object.freeze(s)}var r,t={exports:{}};var i,o=r?t.exports:(r=1,i="undefined"==typeof window?t.exports:window,t.exports=(s=>(()=>{var e={944:e=>{e.exports=s}},r={};function t(s){var i=r[s];if(void 0!==i)return i.exports;var o=r[s]={exports:{}};return e[s](o,o.exports,t),o.exports}t.n=s=>{var e=s&&s.__esModule?()=>s.default:()=>s;return t.d(e,{a:e}),e},t.d=(s,e)=>{for(var r in e)t.o(e,r)&&!t.o(s,r)&&Object.defineProperty(s,r,{enumerable:!0,get:e[r]})},t.o=(s,e)=>Object.prototype.hasOwnProperty.call(s,e);var i={};t.d(i,{default:()=>p});var o=t(944),a=t.n(o);let{composed:l}=a(),{addEvent:c,merge:n,pushUnique:h}=a();function d(){let s=this.options,e=s.lastVisiblePrice,r=s.lastPrice;if((e||r)&&"highcharts-navigator-series"!==s.id){let t=this.xAxis,i=this.yAxis,o=i.crosshair,a=i.cross,l=i.crossLabel,c=this.points,h=c.length,d=this.dataTable.rowCount,p=this.getColumn("x")[d-1],b=this.getColumn("y")[d-1]??this.getColumn("close")[d-1];if(r&&r.enabled&&(i.crosshair=i.options.crosshair=s.lastPrice,!this.chart.styledMode&&i.crosshair&&i.options.crosshair&&s.lastPrice&&(i.crosshair.color=i.options.crosshair.color=s.lastPrice.color||this.color),i.cross=this.lastPrice,this.lastPriceLabel&&this.lastPriceLabel.destroy(),delete i.crossLabel,i.drawCrosshair(null,{x:p,y:b,plotX:t.toPixels(p,!0),plotY:i.toPixels(b,!0)}),this.yAxis.cross&&(this.lastPrice=this.yAxis.cross,this.lastPrice.addClass("highcharts-color-"+this.colorIndex),this.lastPrice.y=b),this.lastPriceLabel=i.crossLabel),e&&e.enabled&&h>0){i.crosshair=i.options.crosshair=n({color:"transparent"},s.lastVisiblePrice),i.cross=this.lastVisiblePrice;let e=c[h-1].isInside?c[h-1]:c[h-2];this.lastVisiblePriceLabel&&this.lastVisiblePriceLabel.destroy(),delete i.crossLabel,i.drawCrosshair(null,e),i.cross&&(this.lastVisiblePrice=i.cross,e&&"number"==typeof e.y&&(this.lastVisiblePrice.y=e.y)),this.lastVisiblePriceLabel=i.crossLabel}i.crosshair=i.options.crosshair=o,i.cross=a,i.crossLabel=l}}!function(s){h(l,"PriceIndication")&&c(s,"afterRender",d)}(a().Series);let p=a();return i.default})())(i._Highcharts)),a=e({__proto__:null,default:s(o)},[o]);export{a as p};
//# sourceMappingURL=price-indicator-B7nYrL9k.js.map
