import{g as t}from"./index-B1MHyEgd.js";function r(t,r){return r.forEach(function(r){r&&"string"!=typeof r&&!Array.isArray(r)&&Object.keys(r).forEach(function(e){if("default"!==e&&!(e in t)){var o=Object.getOwnPropertyDescriptor(r,e);Object.defineProperty(t,e,o.get?o:{enumerable:!0,get:function(){return r[e]}})}})}),Object.freeze(t)}var e,o={exports:{}};var i,n=e?o.exports:(e=1,i="undefined"==typeof window?o.exports:window,o.exports=((t,r)=>(()=>{var e={512:t=>{t.exports=r},944:r=>{r.exports=t}},o={};function i(t){var r=o[t];if(void 0!==r)return r.exports;var n=o[t]={exports:{}};return e[t](n,n.exports,i),n.exports}i.n=t=>{var r=t&&t.__esModule?()=>t.default:()=>t;return i.d(r,{a:r}),r},i.d=(t,r)=>{for(var e in r)i.o(r,e)&&!i.o(t,e)&&Object.defineProperty(t,e,{enumerable:!0,get:r[e]})},i.o=(t,r)=>Object.prototype.hasOwnProperty.call(t,r);var n={};i.d(n,{default:()=>x});var a=i(944),s=i.n(a),p=i(512),h=i.n(p);let{animObject:l}=s(),{series:c,seriesTypes:{scatter:d}}=h(),{arrayMax:g,extend:u,merge:f,pick:y}=s();class b extends d{animate(t){t?this.markerGroup.attr({opacity:.01}):this.markerGroup.animate({opacity:1},l(this.options.animation))}arrow(t){let r=t.length/this.lengthMax*this.options.vectorLength/20,e={start:10*r,center:0,end:-10*r}[this.options.rotationOrigin]||0;return[["M",0,7*r+e],["L",-1.5*r,7*r+e],["L",0,10*r+e],["L",1.5*r,7*r+e],["L",0,7*r+e],["L",0,-10*r+e]]}drawPoints(){let t=this.chart;for(let r of this.points){let e=r.plotX,o=r.plotY;!1===this.options.clip||t.isInsidePlot(e,o,{inverted:t.inverted})?(r.graphic||(r.graphic=this.chart.renderer.path().add(this.markerGroup).addClass("highcharts-point highcharts-color-"+y(r.colorIndex,r.series.colorIndex))),r.graphic.attr({d:this.arrow(r),translateX:e,translateY:o,rotation:r.direction}),this.chart.styledMode||r.graphic.attr(this.pointAttribs(r))):r.graphic&&(r.graphic=r.graphic.destroy())}}pointAttribs(t,r){let e=this.options,o=t?.color||this.color,i=this.options.lineWidth;return r&&(o=e.states[r].color||o,i=(e.states[r].lineWidth||i)+(e.states[r].lineWidthPlus||0)),{stroke:o,"stroke-width":i}}translate(){c.prototype.translate.call(this),this.lengthMax=g(this.getColumn("length"))}}b.defaultOptions=f(d.defaultOptions,{lineWidth:2,marker:void 0,rotationOrigin:"center",states:{hover:{lineWidthPlus:1}},tooltip:{pointFormat:"<b>[{point.x}, {point.y}]</b><br/>Length: <b>{point.length}</b><br/>Direction: <b>{point.direction}°</b><br/>"},vectorLength:20}),u(b.prototype,{drawGraph:s().noop,getSymbol:s().noop,markerAttribs:s().noop,parallelArrays:["x","y","length","direction"],pointArrayMap:["y","length","direction"]}),h().registerSeriesType("vector",b);let x=s();return n.default})())(i._Highcharts,i._Highcharts.SeriesRegistry)),a=r({__proto__:null,default:t(n)},[n]);export{a as v};
//# sourceMappingURL=vector-Dlo_Ci8D.js.map
