import{g as e}from"./index-B1MHyEgd.js";function r(e,r){return r.forEach(function(r){r&&"string"!=typeof r&&!Array.isArray(r)&&Object.keys(r).forEach(function(t){if("default"!==t&&!(t in e)){var n=Object.getOwnPropertyDescriptor(r,t);Object.defineProperty(e,t,n.get?n:{enumerable:!0,get:function(){return r[t]}})}})}),Object.freeze(e)}var t,n={exports:{}};var o,a=(t||(t=1,o="undefined"==typeof window?n.exports:window,n.exports=((e,r)=>(()=>{var t={512:e=>{e.exports=r},944:r=>{r.exports=e}},n={};function o(e){var r=n[e];if(void 0!==r)return r.exports;var a=n[e]={exports:{}};return t[e](a,a.exports,o),a.exports}o.n=e=>{var r=e&&e.__esModule?()=>e.default:()=>e;return o.d(r,{a:r}),r},o.d=(e,r)=>{for(var t in r)o.o(r,t)&&!o.o(e,t)&&Object.defineProperty(e,t,{enumerable:!0,get:r[t]})},o.o=(e,r)=>Object.prototype.hasOwnProperty.call(e,r);var a={};o.d(a,{default:()=>l});var s=o(944),i=o.n(s),p=o(512),d=o.n(p);let{funnel3d:f}=d().seriesTypes,{merge:u}=i();class c extends f{}c.defaultOptions=u(f.defaultOptions,{reversed:!0,neckHeight:0,neckWidth:0,dataLabels:{verticalAlign:"top"}}),d().registerSeriesType("pyramid3d",c);let l=i();return a.default})())(o._Highcharts,o._Highcharts.SeriesRegistry)),n.exports),s=r({__proto__:null,default:e(a)},[a]);export{s as p};
//# sourceMappingURL=pyramid3d-nXqOMrD6.js.map
