import{g as t}from"./index-B1MHyEgd.js";function e(t,e){return e.forEach(function(e){e&&"string"!=typeof e&&!Array.isArray(e)&&Object.keys(e).forEach(function(r){if("default"!==r&&!(r in t)){var o=Object.getOwnPropertyDescriptor(e,r);Object.defineProperty(t,r,o.get?o:{enumerable:!0,get:function(){return e[r]}})}})}),Object.freeze(t)}var r,o={exports:{}};var a,n=r?o.exports:(r=1,a="undefined"==typeof window?o.exports:window,o.exports=(t=>(()=>{var e={944:e=>{e.exports=t}},r={};function o(t){var a=r[t];if(void 0!==a)return a.exports;var n=r[t]={exports:{}};return e[t](n,n.exports,o),n.exports}o.n=t=>{var e=t&&t.__esModule?()=>t.default:()=>t;return o.d(e,{a:e}),e},o.d=(t,e)=>{for(var r in e)o.o(e,r)&&!o.o(t,r)&&Object.defineProperty(t,r,{enumerable:!0,get:e[r]})},o.o=(t,e)=>Object.prototype.hasOwnProperty.call(t,e);var a={};o.d(a,{default:()=>x});var n=o(944),i=o.n(n);let{composed:l}=i(),{addEvent:s,merge:c,pushUnique:f,wrap:u}=i(),p={color:"#ccd3ff",width:2,label:{format:"%[abdYHM]",formatter:function(t,e){return this.axis.chart.time.dateFormat(e||"",t,!0)},rotation:0,style:{fontSize:"0.7em"}}};function d(){let t=this.options,e=t.currentDateIndicator;if(e){let r="object"==typeof e?c(p,e):c(p);r.value=Date.now(),r.className="highcharts-current-date-indicator",t.plotLines||(t.plotLines=[]),t.plotLines.push(r)}}function h(){this.label&&this.label.attr({text:this.getLabelText(this.options.label)})}function b(t,e){let r=this.options;return r&&r.className&&-1!==r.className.indexOf("highcharts-current-date-indicator")&&r.label&&"function"==typeof r.label.formatter?(r.value=Date.now(),r.label.formatter.call(this,r.value,r.label.format)):t.call(this,e)}let m=i();!function(t,e){f(l,"CurrentDateIndication")&&(s(t,"afterSetOptions",d),s(e,"render",h),u(e.prototype,"getLabelText",b))}(m.Axis,m.PlotLineOrBand);let x=i();return a.default})())(a._Highcharts)),i=e({__proto__:null,default:t(n)},[n]);export{i as c};
//# sourceMappingURL=current-date-indicator-CL-Hjmq1.js.map
