import{g as e}from"./index-B1MHyEgd.js";function t(e,t){return t.forEach(function(t){t&&"string"!=typeof t&&!Array.isArray(t)&&Object.keys(t).forEach(function(r){if("default"!==r&&!(r in e)){var a=Object.getOwnPropertyDescriptor(t,r);Object.defineProperty(e,r,a.get?a:{enumerable:!0,get:function(){return t[r]}})}})}),Object.freeze(e)}var r,a={exports:{}};var s,n=r?a.exports:(r=1,s="undefined"==typeof window?a.exports:window,a.exports=((e,t)=>(()=>{var r={512:e=>{e.exports=t},944:t=>{t.exports=e}},a={};function s(e){var t=a[e];if(void 0!==t)return t.exports;var n=a[e]={exports:{}};return r[e](n,n.exports,s),n.exports}s.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return s.d(t,{a:t}),t},s.d=(e,t)=>{for(var r in t)s.o(t,r)&&!s.o(e,r)&&Object.defineProperty(e,r,{enumerable:!0,get:t[r]})},s.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t);var n={};s.d(n,{default:()=>y});var o=s(944),i=s.n(o),p=s(512),d=s.n(p);let{areaspline:f}=d().seriesTypes,{addEvent:l,merge:c,extend:u}=i();class x extends f{streamStacker(e,t,r){e[0]-=t.total/2,e[1]-=t.total/2,this.stackedYData&&(this.stackedYData[r]=Math.max.apply(0,e))}}x.defaultOptions=c(f.defaultOptions,{fillOpacity:1,lineWidth:0,marker:{enabled:!1},stacking:"stream"}),l(x,"afterGetExtremes",e=>{e.dataExtremes.dataMin=-e.dataExtremes.dataMax}),u(x.prototype,{negStacks:!1}),d().registerSeriesType("streamgraph",x);let y=i();return n.default})())(s._Highcharts,s._Highcharts.SeriesRegistry)),o=t({__proto__:null,default:e(n)},[n]);export{o as s};
//# sourceMappingURL=streamgraph-B3BqVEJA.js.map
