import{g as e}from"./index-B1MHyEgd.js";function t(e,t){return t.forEach(function(t){t&&"string"!=typeof t&&!Array.isArray(t)&&Object.keys(t).forEach(function(s){if("default"!==s&&!(s in e)){var r=Object.getOwnPropertyDescriptor(t,s);Object.defineProperty(e,s,r.get?r:{enumerable:!0,get:function(){return t[s]}})}})}),Object.freeze(e)}var s,r={exports:{}};var i,n=s?r.exports:(s=1,i="undefined"==typeof window?r.exports:window,r.exports=((e,t,s)=>(()=>{var r,i={512:e=>{e.exports=s},820:e=>{e.exports=t},944:t=>{t.exports=e}},n={};function a(e){var t=n[e];if(void 0!==t)return t.exports;var s=n[e]={exports:{}};return i[e](s,s.exports,a),s.exports}a.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return a.d(t,{a:t}),t},a.d=(e,t)=>{for(var s in t)a.o(t,s)&&!a.o(e,s)&&Object.defineProperty(e,s,{enumerable:!0,get:t[s]})},a.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t);var o={};a.d(o,{default:()=>E});var d=a(944),p=a.n(d),h=a(820),u=a.n(h);let{noop:l}=p(),{addEvent:c,defined:f}=p();!function(e){function t(){u().prototype.init.apply(this,arguments),this.initialised=!1,this.baseSeries=null,this.eventRemovers=[],this.addEvents()}function s(){let e=this.chart,t=this.options.baseSeries,s=f(t)&&(e.series[t]||e.get(t));this.baseSeries=s||null}function r(){this.eventRemovers.push(c(this.chart,"afterLinkSeries",()=>{this.setBaseSeries(),this.baseSeries&&!this.initialised&&(this.setDerivedData(),this.addBaseSeriesEvents(),this.initialised=!0)}))}function i(){this.eventRemovers.push(c(this.baseSeries,"updatedData",()=>{this.setDerivedData()}),c(this.baseSeries,"destroy",()=>{this.baseSeries=null,this.initialised=!1}))}function n(){this.eventRemovers.forEach(e=>{e()}),u().prototype.destroy.apply(this,arguments)}e.hasDerivedData=!0,e.setDerivedData=l,e.compose=function(e){let a=e.prototype;return a.addBaseSeriesEvents=i,a.addEvents=r,a.destroy=n,a.init=t,a.setBaseSeries=s,e},e.init=t,e.setBaseSeries=s,e.addEvents=r,e.addBaseSeriesEvents=i,e.destroy=n}(r||(r={}));let v=r;var y=a(512),S=a.n(y);let{line:b}=S().seriesTypes,{correctFloat:x,merge:D,extend:m}=p();class g extends b{sumPointsPercents(e,t,s,r){let i,n=[],a=0,o=0,d=0;for(let p of e)null!==p&&(r?o+=p:(i=p/s*100,n.push([t[a],x(d+i)]),d+=i)),++a;return r?o:n}setDerivedData(){let e=this.baseSeries?.getColumn("x")||[],t=this.baseSeries?.getColumn("y")||[],s=this.sumPointsPercents(t,e,null,!0);this.setData(this.sumPointsPercents(t,e,s,!1),!1)}}g.defaultOptions=D(b.defaultOptions,{zIndex:3}),m(g.prototype,{hasDerivedData:v.hasDerivedData}),v.compose(g),S().registerSeriesType("pareto",g);let E=p();return o.default})())(i._Highcharts,i._Highcharts.Series,i._Highcharts.SeriesRegistry)),a=t({__proto__:null,default:e(n)},[n]);export{a as p};
//# sourceMappingURL=pareto-Bezd1IUF.js.map
