import{g as e}from"./index-B1MHyEgd.js";function t(e,t){return t.forEach(function(t){t&&"string"!=typeof t&&!Array.isArray(t)&&Object.keys(t).forEach(function(r){if("default"!==r&&!(r in e)){var i=Object.getOwnPropertyDescriptor(t,r);Object.defineProperty(e,r,i.get?i:{enumerable:!0,get:function(){return t[r]}})}})}),Object.freeze(e)}var r,i={exports:{}};var o,n=r?i.exports:(r=1,o="undefined"==typeof window?i.exports:window,i.exports=(e=>(()=>{let t;var r={944:t=>{t.exports=e}},i={};function o(e){var t=i[e];if(void 0!==t)return t.exports;var n=i[e]={exports:{}};return r[e](n,n.exports,o),n.exports}o.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return o.d(t,{a:t}),t},o.d=(e,t)=>{for(var r in t)o.o(t,r)&&!o.o(e,r)&&Object.defineProperty(e,r,{enumerable:!0,get:t[r]})},o.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t);var n={};o.d(n,{default:()=>O});var s=o(944),a=o.n(s);let{defined:l,isNumber:u,pick:f}=a(),{addEvent:h,isObject:p,pick:d,defined:x,merge:c}=a(),{getAssignedAxis:m}={getAssignedAxis:function(e){return e.filter(e=>{let t=e.axis.getExtremes(),r=t.min,i=t.max,o=f(e.axis.minPointOffset,0);return u(r)&&u(i)&&e.value>=r-o&&e.value<=i+o&&!e.axis.options.isInternal})[0]}},g=[],y={enabled:!0,sensitivity:1.1},v=function(e,r,i,o,n,s,a){let l=d(a.type,e.zooming.type,""),u=[];"x"===l?u=i:"y"===l?u=o:"xy"===l&&(u=e.axes);let f=e.transform({axes:u,to:{x:n-5,y:s-5,width:10,height:10},from:{x:n-5*r,y:s-5*r,width:10*r,height:10*r},trigger:"mousewheel"});return f&&(x(t)&&clearTimeout(t),t=setTimeout(()=>{e.pointer?.drop()},400)),f};function b(){let e=(e=>(p(e)||(e={enabled:e??!0}),c(y,e)))(this.zooming.mouseWheel);e.enabled&&h(this.container,"wheel",t=>{t=this.pointer?.normalize(t)||t;let{pointer:r}=this,i=r&&!r.inClass(t.target,"highcharts-no-mousewheel");if(this.isInsidePlot(t.chartX-this.plotLeft,t.chartY-this.plotTop)&&i){let i=e.sensitivity||1.1,o=t.detail||(t.deltaY||0)/120,n=m(r.getCoordinates(t).xAxis),s=m(r.getCoordinates(t).yAxis);v(this,Math.pow(i,o),n?[n.axis]:this.xAxis,s?[s.axis]:this.yAxis,t.chartX,t.chartY,e)&&t.preventDefault?.()}})}let w=a();w.MouseWheelZoom=w.MouseWheelZoom||{compose:function(e){-1===g.indexOf(e)&&(g.push(e),h(e,"afterGetContainer",b))}},w.MouseWheelZoom.compose(w.Chart);let O=a();return n.default})())(o._Highcharts)),s=t({__proto__:null,default:e(n)},[n]);export{s as m};
//# sourceMappingURL=mouse-wheel-zoom-B3TPgdzu.js.map
