import{g as t}from"./index-B1MHyEgd.js";function e(t,e){return e.forEach(function(e){e&&"string"!=typeof e&&!Array.isArray(e)&&Object.keys(e).forEach(function(a){if("default"!==a&&!(a in t)){var o=Object.getOwnPropertyDescriptor(e,a);Object.defineProperty(t,a,o.get?o:{enumerable:!0,get:function(){return e[a]}})}})}),Object.freeze(t)}var a,o={exports:{}};var r,n=a?o.exports:(a=1,r="undefined"==typeof window?o.exports:window,o.exports=((t,e)=>(()=>{var a={660:t=>{t.exports=e},944:e=>{e.exports=t}},o={};function r(t){var e=o[t];if(void 0!==e)return e.exports;var n=o[t]={exports:{}};return a[t](n,n.exports,r),n.exports}r.n=t=>{var e=t&&t.__esModule?()=>t.default:()=>t;return r.d(e,{a:e}),e},r.d=(t,e)=>{for(var a in e)r.o(e,a)&&!r.o(t,a)&&Object.defineProperty(t,a,{enumerable:!0,get:e[a]})},r.o=(t,e)=>Object.prototype.hasOwnProperty.call(t,e);var n={};r.d(n,{default:()=>x});var i=r(944),s=r.n(i),l=r(660),d=r.n(l);let h={lang:{noData:"No data to display"},noData:{attr:{zIndex:1},position:{x:0,y:0,align:"center",verticalAlign:"middle"},style:{fontWeight:"bold",fontSize:"0.8em",color:"#666666"}}},{addEvent:f,extend:p,merge:u}=s();function c(){let t=this.series||[],e=t.length;for(;e--;)if(t[e].hasData()&&!t[e].options.isInternal)return!0;return this.loadingShown}function D(){this.noDataLabel&&(this.noDataLabel=this.noDataLabel.destroy())}function b(t){let e=this.options,a=t||e&&e.lang.noData||"",o=e&&(e.noData||{});this.renderer&&(this.noDataLabel||(this.noDataLabel=this.renderer.label(a,0,0,void 0,void 0,void 0,o.useHTML,void 0,"no-data").add()),this.styledMode||this.noDataLabel.attr(d().filterUserAttributes(o.attr||{})).css(o.style||{}),this.noDataLabel.align(p(this.noDataLabel.getBBox(),o.position||{}),!1,"plotBox"))}function g(){this.hasData()?this.hideNoData():this.showNoData()}let v=s();!function(t,e){let a=t.prototype;a.showNoData||(a.hasData=c,a.hideNoData=D,a.showNoData=b,f(t,"render",g),u(!0,e,h))}(v.Chart,v.defaultOptions);let x=s();return n.default})())(r._Highcharts,r._Highcharts.AST)),i=e({__proto__:null,default:t(n)},[n]);export{i as n};
//# sourceMappingURL=no-data-to-display-C--9oCjo.js.map
