import{g as e}from"./index-B1MHyEgd.js";function t(e,t){return t.forEach(function(t){t&&"string"!=typeof t&&!Array.isArray(t)&&Object.keys(t).forEach(function(r){if("default"!==r&&!(r in e)){var i=Object.getOwnPropertyDescriptor(t,r);Object.defineProperty(e,r,i.get?i:{enumerable:!0,get:function(){return t[r]}})}})}),Object.freeze(e)}var r,i={exports:{}};var s,o=r?i.exports:(r=1,s="undefined"==typeof window?i.exports:window,i.exports=((e,t)=>(()=>{var r={512:e=>{e.exports=t},944:t=>{t.exports=e}},i={};function s(e){var t=i[e];if(void 0!==t)return t.exports;var o=i[e]={exports:{}};return r[e](o,o.exports,s),o.exports}s.n=e=>{var t=e&&e.__esModule?()=>e.default:()=>e;return s.d(t,{a:t}),t},s.d=(e,t)=>{for(var r in t)s.o(t,r)&&!s.o(e,r)&&Object.defineProperty(e,r,{enumerable:!0,get:t[r]})},s.o=(e,t)=>Object.prototype.hasOwnProperty.call(e,t);var o={};s.d(o,{default:()=>y});var a=s(944),n=s.n(a),d=s(512),p=s.n(d);let{column:l}=p().seriesTypes,{extend:c,isNumber:h,merge:f,pick:u}=n();class g extends l{drawPoints(){let e=this.options,t=this.chart.renderer,r=e.marker,i=this.points.reduce((e,t)=>e+Math.abs(t.y||0),0),s=this.points.reduce((e,t)=>e+(t.shapeArgs?.height||0),0),o=e.itemPadding||0,a=this.points[0]?.shapeArgs?.width||0,n=e.slotsPerBar,d=a;if(!h(n))for(n=1;n<i&&!(i/n<s/d*1.2);)d=a/++n;let p=s*n/i;for(let e of this.points){let i,s=e.marker||{},a=s.symbol||r.symbol,l=u(s.radius,r.radius),h="rect"!==a?p:d,f=e.shapeArgs||{},g=(f.x||0)+((f.width||0)-n*h)/2,y=Math.abs(e.y??0),m=f.y||0,v=f.height||0,b=g,x=e.negative?m:m+v-p,A=0;e.graphics=i=e.graphics||[];let w=e.pointAttr?e.pointAttr[e.selected?"selected":""]||this.pointAttr[""]:this.pointAttribs(e,e.selected&&"select");if(delete w.r,this.chart.styledMode&&(delete w.stroke,delete w["stroke-width"]),"number"==typeof e.y){e.graphic||(e.graphic=t.g("point").add(this.group));for(let r=0;r<y;r++){let s={x:b+h*o,y:x+p*o,width:h*(1-2*o),height:p*(1-2*o),r:l},d=i[r];d?d.animate(s):d=t.symbol(a).attr(c(s,w)).add(e.graphic),d.isActive=!0,i[r]=d,b+=h,++A>=n&&(A=0,b=g,x=e.negative?x+p:x-p)}}let O=-1;for(let e of i)++O,e&&(e.isActive?e.isActive=!1:(e.destroy(),i.splice(O,1)))}}}g.defaultOptions=f(l.defaultOptions,{itemPadding:.1,marker:{symbol:"circle",states:{hover:{},select:{}}},slotsPerBar:void 0}),c(g.prototype,{markerAttribs:void 0}),p().registerSeriesType("dotplot",g);let y=n();return o.default})())(s._Highcharts,s._Highcharts.SeriesRegistry)),a=t({__proto__:null,default:e(o)},[o]);export{a as d};
//# sourceMappingURL=dotplot-Dn3rvcYV.js.map
