import{g as t}from"./index-B1MHyEgd.js";function e(t,e){return e.forEach(function(e){e&&"string"!=typeof e&&!Array.isArray(e)&&Object.keys(e).forEach(function(r){if("default"!==r&&!(r in t)){var o=Object.getOwnPropertyDescriptor(e,r);Object.defineProperty(t,r,o.get?o:{enumerable:!0,get:function(){return e[r]}})}})}),Object.freeze(t)}var r,o={exports:{}};var a,i=r?o.exports:(r=1,a="undefined"==typeof window?o.exports:window,o.exports=((t,e,r)=>(()=>{var o={448:t=>{t.exports=e},512:t=>{t.exports=r},944:e=>{e.exports=t}},a={};function i(t){var e=a[t];if(void 0!==e)return e.exports;var r=a[t]={exports:{}};return o[t](r,r.exports,i),r.exports}i.n=t=>{var e=t&&t.__esModule?()=>t.default:()=>t;return i.d(e,{a:e}),e},i.d=(t,e)=>{for(var r in e)i.o(e,r)&&!i.o(t,r)&&Object.defineProperty(t,r,{enumerable:!0,get:e[r]})},i.o=(t,e)=>Object.prototype.hasOwnProperty.call(t,e);var s={};i.d(s,{default:()=>v});var n=i(944),p=i.n(n),l=i(448),d=i.n(l);class h extends d().prototype.pointClass{destroy(){this.targetGraphic&&(this.targetGraphic=this.targetGraphic.destroy()),super.destroy.apply(this,arguments)}}var c=i(512),g=i.n(c);let{extend:u,isNumber:y,merge:x,pick:f,relativeLength:b}=p();class m extends(d()){drawPoints(){let t=this.chart,e=this.options,r=e.animationLimit||250;for(let o of(super.drawPoints.apply(this,arguments),this.points)){let a,i,s,n,p,l=o.options,d=o.target,h=o.y,c=o.targetGraphic;if(y(d)&&null!==d){s=(n=x(e.targetOptions,l.targetOptions)).height;let g=o.shapeArgs;o.dlBox&&g&&!y(g.width)&&(g=o.dlBox),i=b(n.width,g.width),p=this.yAxis.translate(d,!1,!0,!1,!0)-n.height/2-.5,a=this.crispCol.apply({chart:t,borderWidth:n.borderWidth,options:{crisp:e.crisp}},[g.x+g.width/2-i/2,p,i,s]),c?(c[t.pointCount<r?"animate":"attr"](a),y(h)&&null!==h?c.element.point=o:c.element.point=void 0):o.targetGraphic=c=t.renderer.rect().attr(a).add(this.group),t.styledMode||c.attr({fill:f(n.color,l.color,this.zones.length&&(o.getZone.call({series:this,x:o.x,y:d,options:{}}).color||this.color)||void 0,o.color,this.color),stroke:f(n.borderColor,o.borderColor,this.options.borderColor),"stroke-width":n.borderWidth,r:n.borderRadius}),y(h)&&null!==h&&(c.element.point=o),c.addClass(o.getClassName()+" highcharts-bullet-target",!0)}else c&&(o.targetGraphic=c.destroy())}}getExtremes(t){let e=super.getExtremes.call(this,t),r=this.targetData;if(r&&r.length){let t=super.getExtremes.call(this,r);y(t.dataMin)&&(e.dataMin=Math.min(f(e.dataMin,1/0),t.dataMin)),y(t.dataMax)&&(e.dataMax=Math.max(f(e.dataMax,-1/0),t.dataMax))}return e}}m.defaultOptions=x(d().defaultOptions,{targetOptions:{width:"140%",height:3,borderWidth:0,borderRadius:0},tooltip:{pointFormat:'<span style="color:{series.color}">●</span> {series.name}: <b>{point.y}</b>. Target: <b>{point.target}</b><br/>'}}),u(m.prototype,{parallelArrays:["x","y","target"],pointArrayMap:["y","target"]}),m.prototype.pointClass=h,g().registerSeriesType("bullet",m);let v=p();return s.default})())(a._Highcharts,a._Highcharts.Series.types.column,a._Highcharts.SeriesRegistry)),s=e({__proto__:null,default:t(i)},[i]);export{s as b};
//# sourceMappingURL=bullet-BZCcyGbt.js.map
