import{g as t}from"./index-B1MHyEgd.js";function e(t,e){return e.forEach(function(e){e&&"string"!=typeof e&&!Array.isArray(e)&&Object.keys(e).forEach(function(r){if("default"!==r&&!(r in t)){var i=Object.getOwnPropertyDescriptor(e,r);Object.defineProperty(t,r,i.get?i:{enumerable:!0,get:function(){return e[r]}})}})}),Object.freeze(t)}var r,i={exports:{}};var a,o=r?i.exports:(r=1,a="undefined"==typeof window?i.exports:window,i.exports=(t=>(()=>{var e={944:e=>{e.exports=t}},r={};function i(t){var a=r[t];if(void 0!==a)return a.exports;var o=r[t]={exports:{}};return e[t](o,o.exports,i),o.exports}i.n=t=>{var e=t&&t.__esModule?()=>t.default:()=>t;return i.d(e,{a:e}),e},i.d=(t,e)=>{for(var r in e)i.o(e,r)&&!i.o(t,r)&&Object.defineProperty(t,r,{enumerable:!0,get:e[r]})},i.o=(t,e)=>Object.prototype.hasOwnProperty.call(t,e);var a={};i.d(a,{default:()=>f});var o=i(944),s=i.n(o);let{addEvent:n,defined:l,isNumber:h}=s();function c(){let t=this.chart.userOptions.chart;!this.horiz&&h(this.options.staticScale)&&(!t?.height||t.scrollablePlotArea?.minHeight)&&(this.staticScale=this.options.staticScale)}function d(){if("adjustHeight"!==this.redrawTrigger){for(let t of this.axes||[]){let e=t.chart,r=t.options.staticScale;if(t.staticScale&&r&&l(t.min)&&l(t.max)){let i=(t.brokenAxis?.unitLength??t.max+t.tickInterval-t.min)*r,a=(i=Math.max(i,r))-e.plotHeight;!e.scrollablePixelsY&&Math.abs(a)>=1&&(e.plotHeight=i,e.redrawTrigger="adjustHeight",e.setSize(void 0,e.chartHeight+a,!!e.initiatedScale&&void 0)),t.series.forEach(function(t){let r=t.sharedClipKey&&e.sharedClips[t.sharedClipKey];r&&r.attr(e.inverted?{width:e.plotHeight}:{height:e.plotHeight})})}}this.initiatedScale=!0}this.redrawTrigger=void 0}let p=s();!function(t,e){let r=e.prototype;r.adjustHeight||(n(t,"afterSetOptions",c),r.adjustHeight=d,n(e,"render",r.adjustHeight))}(p.Axis,p.Chart);let f=s();return a.default})())(a._Highcharts)),s=e({__proto__:null,default:t(o)},[o]);export{s};
//# sourceMappingURL=static-scale-DPzxabv7.js.map
